###################################################
### chunk number 1: 
###################################################
#line 73 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	options(prompt = "R> ", continue = "+  ", width = 70, useFancyQuotes = FALSE)
	library(lifecontingencies)
	source("calculations1.R")


###################################################
### chunk number 2:  eval=FALSE
###################################################
## #line 80 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
## 	source("calculations2.R")


###################################################
### chunk number 3: load
###################################################
#line 170 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	library(lifecontingencies)


###################################################
### chunk number 4: show classes
###################################################
#line 178 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	#definition of lifetable
	showClass("lifetable")


###################################################
### chunk number 5: show actuarial
###################################################
#line 186 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	showClass("actuarialtable")


###################################################
### chunk number 6: present value
###################################################
#line 219 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	#say we are at time t0, and following capitals would have been received (+) / paid (-)
	#at time (vector) t.
	capitals=c(-1000,200,500,700)
	times=c(-2,-1,4,7)
	#the preset value of the investment is 
	presentValue(cashFlows=capitals, timeIds=times, interestRates=0.03)
	#@3% interest rate
	#while if interest rates were time - varying 0.04 0.02 0.03 0.057
	presentValue(cashFlows=capitals, timeIds=times, interestRates=c( 0.04, 0.02, 0.03, 0.057))
	#and if the last cash flow is uncertain, as we assume a receiving probability of 50% 
	presentValue(cashFlows=capitals, timeIds=times, interestRates=c( 0.04, 0.02, 0.03, 0.057), probabilities=c(1,1,1,0.5))


###################################################
### chunk number 7: capital amortization
###################################################
#line 236 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
capital=100000
interest=0.05 #assume 5% of interest
payments_per_year=2 #montly paymentsa
effectiveRate=(1+interest)^(1/payments_per_year)-1
years=10 #ten years length of the loan
installment=capital/annuity(i=effectiveRate, periods=years*payments_per_year)
installment	
#compute the balance fue
balance_due=numeric(years*payments_per_year)
balance_due[1]=capital*(1+effectiveRate)-installment
for(i in 2:length(balance_due)) 
{
	balance_due[i]=balance_due[i-1]*(1+effectiveRate)-installment
	cat("Payment ",i, " balance due:",round(balance_due[i]),"\n")
}



###################################################
### chunk number 8: savings account projection
###################################################
#line 257 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	#assume the bank will grant a yearly interest of 2.5% on effectively 
	#invested amounts
	#the bank will charge a service charge of $1 and a service fee of 
	#0.01 on the amount between 0 and 100, 0.005 on the amounts between 100 and 150 and 0 thereafter


	cumulatedSavings<-function(amount, rate, periods)
	{
		service_charge=1
		service_fee=(0.01*min(100,amount)+0.005*max(0,min(50,amount-100)))
		invested_amount=amount-service_charge-service_fee
		out=invested_amount*accumulatedValue(interestRates=rate, periods=periods)
		return(out)
	}
	
	savings_sequence=seq(from=50, to=300, by=10) #possible montly savings
	periods=30*12 #suppose 30 years of savings
	yearly_rate=0.025 #suppose a APR of 2.5 that is a 
	montly_effective_rate=(1+yearly_rate)^(1/12)-1
	
	cumulated_value=sapply(savings_sequence, cumulatedSavings, montly_effective_rate, periods)
	#plot(savings_sequence, cumulated_value, type="l")	


###################################################
### chunk number 9: interest rates
###################################################
#line 285 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
#4% per year compounded quarterly is
nominal2Real(0.04,4)
#4% effective interest rate corresponds to 
real2Nominal(0.04,4)*100
#nominal interest rate (in 100s) compounded quarterly


###################################################
### chunk number 10: create a lifecontingencies object
###################################################
#line 308 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	x_example=seq(from=0,to=9, by=1)
	lx_example=c(1000,950,850,700,680,600,550,400,200,50)
	fakeLt=new("lifetable",x=x_example, lx=lx_example, name="fake lifetable")


###################################################
### chunk number 11: print - show
###################################################
#line 315 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	print(fakeLt)


###################################################
### chunk number 12: create a actuarialtable object
###################################################
#line 321 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	irate=0.03
	fakeAct=new("actuarialtable",x=fakeLt@x, lx=fakeLt@lx, interest=irate, name="fake actuarialtable")


###################################################
### chunk number 13: method
###################################################
#line 329 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	getOmega(fakeAct)


###################################################
### chunk number 14: probability and demographics
###################################################
#line 339 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	pxt(fakeLt,2,1) #probability to survive one year, being at age 2
	qxt(fakeLt,3,2) #probability to die within two years, being at age 3
	exn(fakeLt, 5,2) #expected life time between 5 an 7 years


###################################################
### chunk number 15: fractional ages
###################################################
#line 348 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
  data(soa08Act) #load Society of Actuaries illustrative life table
  pxt(soa08Act,80,0.5,"linear") #linear interpolation (default)
  pxt(soa08Act,80,0.5,"constant force") #constant force 
  pxt(soa08Act,80,0.5,"hyperbolic") #constant force 


###################################################
### chunk number 16: more than one head
###################################################
#line 358 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	pxyt(fakeLt,fakeLt,x=6, y=7, t=2) #joint survival probability
	pxyt(fakeLt,fakeLt,x=6, y=7, t=2,status="last") #last survival probability


###################################################
### chunk number 17: ips55 expected life time
###################################################
#line 365 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
#create the tables

	lxIPS55M<-with(demoita, IPS55M)
	pos2Remove<-which(lxIPS55M %in% c(0,NA))
	lxIPS55M<-lxIPS55M[-pos2Remove]
	xIPS55M<-seq(0,length(lxIPS55M)-1,1)

	lxIPS55F<-with(demoita, IPS55F)
	pos2Remove<-which(lxIPS55F %in% c(0,NA))
	lxIPS55F<-lxIPS55F[-pos2Remove]
	xIPS55F<-seq(0,length(lxIPS55F)-1,1)

	ips55M=new("lifetable",x=xIPS55M, lx=lxIPS55M, name="IPS 55 Males")
	ips55F=new("lifetable",x=xIPS55F, lx=lxIPS55F, name="IPS 55 Females")
	
	#implicit omega age
	
	getOmega(ips55M) #for males
	getOmega(ips55F) #for females

	#evaluate the joint expected life time for a couple 
	#male ages 65 and females ages 63
	exyt(ips55M, ips55F, x=65,y=63, status="joint")
	


###################################################
### chunk number 18: life insurance 1
###################################################
#line 405 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
#The APV of a life insurance for a 10-year term life insurance for an
#insured aged 40 @ 4% interest rate is  
Axn(soa08Act, 30,10,i=0.04)
#same as above but payable at the end of month of death
Axn(soa08Act, x=30,n=10,i=0.04,k=12)
#a whole life for a 40 years old insured at @4% is 
Axn(soa08Act, 40) #soa08Act has 6% implicit interest rate
#a 5-year deferred life insurance, 10 years length, 40 years age, @5% interest rate
Axn(actuarialtable=soa08Act, x=40,n=10,m=5,i=0.05) 
#Five years annually decreasing term life insurance, age 50.
DAxn(soa08Act, 50,5)
#Increasing 20 years term life insurance, age 40
IAxn(soa08Act, 40,10)


###################################################
### chunk number 19: pure endowments
###################################################
#line 423 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	#evaluate the APV for a n year pure endowment, age x=30, n=35, i=6%
	Exn(soa08Act, x=30, n=35, i=0.06)
	#try i=3%
	Exn(soa08Act, x=30, n=35, i=0.03)


###################################################
### chunk number 20: annuities
###################################################
#line 434 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
#assuming insured's age x=65 and SOA illustrative life table @6% hold for all examples 
#annuity immediate
axn(soa08Act, x=65, m=1)
#annuity due
axn(soa08Act, x=65)
#due with montly payments of $1000 provision
12*1000*axn(soa08Act, x=65,k=12)
#due with montly payments of $1000 provision, 20 - years term
12*1000*axn(soa08Act, x=65,k=12, n=20)
#immediate with montly payments of $1000 provision, 20 - years term
12*1000*axn(soa08Act, x=65,k=12,n=20,m=1/12)


###################################################
### chunk number 21: life insurance 2
###################################################
#line 453 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	data(soa08Act) #use SOA MLC exam illustrative life table
	#Assume X, aged 30, whishes to buy a 250K 35-years life insurance
	#premium paid annually for 15 years @2.5%.
	Pa=100000*Axn(soa08Act, x=30,n=35,i=0.025)/axn(soa08Act, x=30,n=15,i=0.025)
	Pa
	#if premium is paid montly
	Pm=100000*Axn(soa08Act, x=30,n=35,i=0.025)/axn(soa08Act, x=30,n=15,i=0.025,k=12)
	Pm


###################################################
### chunk number 22: endowment insurance
###################################################
#line 465 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	#level semiannual premium for an endowment insurance of 10000
	#insured age 50, insurance term is 20 years
	APV=10000*(Axn(soa08Act,50,20)+Exn(soa08Act,50,20))
	P=APV/axn(soa08Act,50,20,k=2)


###################################################
### chunk number 23: life insurance benefit reserve
###################################################
#line 484 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	P=100000*Axn(soa08Act,x=40,n=20,i=0.03)/axn(soa08Act,x=40,n=20,i=0.03)
	for(t in 0:19) cat("At time ",t," benefit reserve is ", 100000*Axn(soa08Act,x=40+t,n=20-t,i=0.03)-P*axn(soa08Act,x=40+t,n=20-t,i=0.03), "\n")


###################################################
### chunk number 24: two heads annuity immediate
###################################################
#line 500 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	axn(soa08Act, x=65,m=1)+axn(soa08Act, x=70,m=1)-axyn(soa08Act,soa08Act, x=65,y=70,status="joint",m=1)
	axyn(soa08Act,soa08Act, x=65,y=70, status="last",m=1)


###################################################
### chunk number 25: revesionary annuity
###################################################
#line 507 "d:/Rcompile/CRANpkg/local/2.12/lifecontingencies/inst/doc/lifecontingenciesVignettes.Rnw"
	#assume x aged 65, y aged 60
	axn(soa08Act, x=60,m=1)-axyn(soa08Act,soa08Act, x=65,y=60,status="joint",m=1)


